componenttools.get_component_stop_offset_in_seconds
===================================================

.. autofunction:: abjad.tools.componenttools.get_component_stop_offset_in_seconds.get_component_stop_offset_in_seconds
